import {CreateArrayTagDirective, CreateControlValueAccessor, CreateComplexDirective, CreateComponent, Utils, ContentChild, Type, forwardRef } from './core';
export var TrendlineDirective = CreateComplexDirective({
    selector: "e-trendlines>e-trendline",
    inputs: ["visibility", "type", "name", "fill", "width", "opacity", "dashArray", "forwardForecast", "backwardForecast", "polynomialOrder", "period"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => ChartComponent)
});


export var TrendlinesDirective = CreateArrayTagDirective("trendlines", 'e-series>e-trendlines', TrendlineDirective);

export var PointDirective = CreateComplexDirective({
    selector: "e-points>e-point",
    inputs: ["border", "visibleOnLegend", "showIntermediateSum", "showTotalSum", "close", "size", "fill", "high", "low", "marker", "open", "text", "x", "y"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => ChartComponent)
});


export var PointsDirective = CreateArrayTagDirective("points", 'e-series>e-points', PointDirective);

export var SeriesDirective = CreateComplexDirective({
    selector: "e-seriescollection>e-series",
    inputs: ["bearFillColor", "border", "bullFillColor", "columnWidth", "columnSpacing", "dashArray", "dataSource", "doughnutCoefficient", "doughnutSize", "drawType", "enableAnimation", "enableSmartLabels", "endAngle", "explode", "explodeAll", "explodeIndex", "explodeOffset", "fill", "font", "funnelHeight", "funnelWidth", "gapRatio", "isClosed", "isStacking", "isTransposed", "labelPosition", "lineCap", "lineJoin", "marker", "name", "opacity", "palette", "pieCoefficient", "emptyPointSettings", "positiveFill", "connectorLine", "errorBar", "points", "pyramidMode", "query", "startAngle", "tooltip", "type", "visibility", "visibleOnLegend", "xAxisName", "xName", "yAxisName", "yName", "high", "low", "open", "close", "pointColorMappingName", "zOrder", "size", "trendlines", "highlightSettings", "selectionSettings"],
    queries: {
        _Trendlines : new ContentChild(TrendlinesDirective),
        _points : new ContentChild(PointsDirective),
    }
}, {
    tags: ["Trendlines", "points" ],
     type: forwardRef(() => ChartComponent)
});


export var SeriesCollectionDirective = CreateArrayTagDirective("series", 'ej-chart>e-seriescollection', SeriesDirective);

export var IndicatorDirective = CreateComplexDirective({
    selector: "e-indicators>e-indicator",
    inputs: ["dPeriod", "enableAnimation", "fill", "histogram", "kPeriod", "longPeriod", "lowerLine", "macdLine", "macdType", "period", "periodLine", "seriesName", "shortPeriod", "standardDeviations", "tooltip", "trigger", "visibility", "type", "upperLine", "width", "xAxisName", "yAxisName"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => ChartComponent)
});


export var IndicatorsDirective = CreateArrayTagDirective("indicators", 'ej-chart>e-indicators', IndicatorDirective);

export var AnnotationDirective = CreateComplexDirective({
    selector: "e-annotations>e-annotation",
    inputs: ["angle", "content", "coordinateUnit", "horizontalAlignment", "margin", "opacity", "region", "verticalAlignment", "visible", "x", "xAxisName", "y", "yAxisName"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => ChartComponent)
});


export var AnnotationsDirective = CreateArrayTagDirective("annotations", 'ej-chart>e-annotations', AnnotationDirective);

export var PrimaryXAxisStripLineDirective = CreateComplexDirective({
    selector: "e-primaryxaxis-striplinecollection>e-primaryxaxis-stripline",
    inputs: ["borderColor", "color", "end", "font", "start", "startFromAxis", "text", "textAlignment", "visible", "width", "zIndex"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => ChartComponent)
});


export var PrimaryXAxisStripLineCollectionDirective = CreateArrayTagDirective("primaryXAxis.stripLine", 'ej-chart>e-primaryxaxis-striplinecollection', PrimaryXAxisStripLineDirective);

export var PrimaryYAxisStripLineDirective = CreateComplexDirective({
    selector: "e-primaryyaxis-striplinecollection>e-primaryyaxis-stripline",
    inputs: ["borderColor", "color", "end", "font", "start", "startFromAxis", "text", "textAlignment", "visible", "width", "zIndex"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => ChartComponent)
});


export var PrimaryYAxisStripLineCollectionDirective = CreateArrayTagDirective("primaryYAxis.stripLine", 'ej-chart>e-primaryyaxis-striplinecollection', PrimaryYAxisStripLineDirective);

export var RowDefinitionDirective = CreateComplexDirective({
    selector: "e-rowdefinitions>e-rowdefinition",
    inputs: ["unit", "rowHeight", "lineColor", "lineWidth"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => ChartComponent)
});


export var RowDefinitionsDirective = CreateArrayTagDirective("rowDefinitions", 'ej-chart>e-rowdefinitions', RowDefinitionDirective);

export var ColumnDefinitionDirective = CreateComplexDirective({
    selector: "e-columndefinitions>e-columndefinition",
    inputs: ["unit", "columnWidth", "lineColor", "lineWidth"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => ChartComponent)
});


export var ColumnDefinitionsDirective = CreateArrayTagDirective("columnDefinitions", 'ej-chart>e-columndefinitions', ColumnDefinitionDirective);


var Outputs = [ "animationComplete", "axesLabelRendering", "axesLabelsInitialize", "axesRangeCalculate", "axesTitleRendering", "chartAreaBoundsCalculate", "create", "destroy", "displayTextRendering", "legendBoundsCalculate", "legendItemClick", "legendItemMouseMove", "legendItemRendering", "load", "pointRegionClick", "pointRegionMouseMove", "preRender", "seriesRegionClick", "seriesRendering", "symbolRendering", "titleRendering", "toolTipInitialize", "trackAxisToolTip", "trackToolTip", "axisLabelClick", "axisLabelMouseMove", "chartClick", "chartMouseMove", "chartDoubleClick", "annotationClick", "afterResize", "beforeResize", "errorBarRendering", "scrollChanged", "scrollStart", "scrollEnd" ];
var ComplexProperties = [ "border", "exportSettings", "chartArea", "commonSeriesOptions", "crosshair", "legend", "primaryXAxis", "primaryYAxis", "size", "title", "zooming", "chartArea.border", "commonSeriesOptions.border", "commonSeriesOptions.font", "commonSeriesOptions.marker", "commonSeriesOptions.marker.border", "commonSeriesOptions.marker.dataLabel", "commonSeriesOptions.marker.dataLabel.border", "commonSeriesOptions.marker.dataLabel.connectorLine", "commonSeriesOptions.marker.dataLabel.font", "commonSeriesOptions.marker.dataLabel.margin", "commonSeriesOptions.marker.size", "commonSeriesOptions.tooltip", "commonSeriesOptions.tooltip.border", "commonSeriesOptions.emptyPointSettings", "commonSeriesOptions.emptyPointSettings.style", "commonSeriesOptions.emptyPointSettings.style.border", "commonSeriesOptions.connectorLine", "commonSeriesOptions.errorBar", "commonSeriesOptions.errorBar.cap", "commonSeriesOptions.highlightSettings", "commonSeriesOptions.highlightSettings.border", "commonSeriesOptions.selectionSettings", "commonSeriesOptions.selectionSettings.border", "crosshair.marker", "crosshair.marker.border", "crosshair.marker.size", "crosshair.line", "legend.border", "legend.font", "legend.itemStyle", "legend.itemStyle.border", "legend.location", "legend.size", "legend.title", "legend.title.font", "primaryXAxis.alternateGridBand", "primaryXAxis.alternateGridBand.even", "primaryXAxis.alternateGridBand.odd", "primaryXAxis.axisLine", "primaryXAxis.crosshairLabel", "primaryXAxis.font", "primaryXAxis.majorGridLines", "primaryXAxis.majorTickLines", "primaryXAxis.minorGridLines", "primaryXAxis.minorTickLines", "primaryXAxis.range", "primaryXAxis.title", "primaryXAxis.title.font", "primaryYAxis.alternateGridBand", "primaryYAxis.alternateGridBand.even", "primaryYAxis.alternateGridBand.odd", "primaryYAxis.axisLine", "primaryYAxis.crosshairLabel", "primaryYAxis.font", "primaryYAxis.majorGridLines", "primaryYAxis.majorTickLines", "primaryYAxis.minorGridLines", "primaryYAxis.minorTickLines", "primaryYAxis.range", "primaryYAxis.title", "primaryYAxis.title.font", "title.border", "title.font", "title.subTitle", "title.subTitle.font", "title.subTitle.border"  ];
var Inputs = Utils.AngularizeInputs( [ "backGroundImageUrl", "border", "exportSettings", "chartArea", "commonSeriesOptions", "crosshair", "depth", "enable3D", "enableCanvasRendering", "enableRotation", "isResponsive", "legend", "locale", "palette", "Margin", "perspectiveAngle", "primaryXAxis", "primaryYAxis", "rotation", "sideBySideSeriesPlacement", "size", "theme", "tilt", "title", "wallSize", "zooming", "border.color", "border.opacity", "border.width", "exportSettings.filename", "exportSettings.action", "exportSettings.angle", "exportSettings.type", "exportSettings.orientation", "exportSettings.mode", "exportSettings.multipleExport", "chartArea.background", "chartArea.border", "chartArea.border.color", "chartArea.border.opacity", "chartArea.border.width", "commonSeriesOptions.border", "commonSeriesOptions.border.color", "commonSeriesOptions.border.dashArray", "commonSeriesOptions.border.width", "commonSeriesOptions.columnWidth", "commonSeriesOptions.columnSpacing", "commonSeriesOptions.visibleOnLegend", "commonSeriesOptions.dashArray", "commonSeriesOptions.dataSource", "commonSeriesOptions.doughnutCoefficient", "commonSeriesOptions.doughnutSize", "commonSeriesOptions.drawType", "commonSeriesOptions.enableAnimation", "commonSeriesOptions.enableSmartLabels", "commonSeriesOptions.endAngle", "commonSeriesOptions.explode", "commonSeriesOptions.explodeAll", "commonSeriesOptions.explodeIndex", "commonSeriesOptions.explodeOffset", "commonSeriesOptions.fill", "commonSeriesOptions.font", "commonSeriesOptions.font.color", "commonSeriesOptions.font.fontFamily", "commonSeriesOptions.font.fontStyle", "commonSeriesOptions.font.fontWeight", "commonSeriesOptions.font.opacity", "commonSeriesOptions.font.size", "commonSeriesOptions.funnelHeight", "commonSeriesOptions.funnelWidth", "commonSeriesOptions.gapRatio", "commonSeriesOptions.isClosed", "commonSeriesOptions.isStacking", "commonSeriesOptions.isTransposed", "commonSeriesOptions.labelPosition", "commonSeriesOptions.lineCap", "commonSeriesOptions.lineJoin", "commonSeriesOptions.marker", "commonSeriesOptions.marker.border", "commonSeriesOptions.marker.dataLabel", "commonSeriesOptions.marker.fill", "commonSeriesOptions.marker.imageUrl", "commonSeriesOptions.marker.opacity", "commonSeriesOptions.marker.shape", "commonSeriesOptions.marker.size", "commonSeriesOptions.marker.visible", "commonSeriesOptions.opacity", "commonSeriesOptions.palette", "commonSeriesOptions.pieCoefficient", "commonSeriesOptions.pointColorMappingName", "commonSeriesOptions.pyramidMode", "commonSeriesOptions.startAngle", "commonSeriesOptions.tooltip", "commonSeriesOptions.tooltip.border", "commonSeriesOptions.tooltip.rx", "commonSeriesOptions.tooltip.ry", "commonSeriesOptions.tooltip.duration", "commonSeriesOptions.tooltip.enableAnimation", "commonSeriesOptions.tooltip.fill", "commonSeriesOptions.tooltip.format", "commonSeriesOptions.tooltip.opacity", "commonSeriesOptions.tooltip.template", "commonSeriesOptions.tooltip.visible", "commonSeriesOptions.type", "commonSeriesOptions.xAxisName", "commonSeriesOptions.xName", "commonSeriesOptions.yAxisName", "commonSeriesOptions.yName", "commonSeriesOptions.high", "commonSeriesOptions.low", "commonSeriesOptions.open", "commonSeriesOptions.close", "commonSeriesOptions.zOrder", "commonSeriesOptions.size", "commonSeriesOptions.emptyPointSettings", "commonSeriesOptions.emptyPointSettings.visible", "commonSeriesOptions.emptyPointSettings.displayMode", "commonSeriesOptions.emptyPointSettings.style", "commonSeriesOptions.positiveFill", "commonSeriesOptions.connectorLine", "commonSeriesOptions.connectorLine.width", "commonSeriesOptions.connectorLine.color", "commonSeriesOptions.connectorLine.dashArray", "commonSeriesOptions.connectorLine.opacity", "commonSeriesOptions.errorBar", "commonSeriesOptions.errorBar.visibility", "commonSeriesOptions.errorBar.type", "commonSeriesOptions.errorBar.mode", "commonSeriesOptions.errorBar.direction", "commonSeriesOptions.errorBar.verticalErrorValue", "commonSeriesOptions.errorBar.horizontalErrorValue", "commonSeriesOptions.errorBar.horizontalPositiveErrorValue", "commonSeriesOptions.errorBar.horizontalNegativeErrorValue", "commonSeriesOptions.errorBar.verticalPositiveErrorValue", "commonSeriesOptions.errorBar.verticalNegativeErrorValue", "commonSeriesOptions.errorBar.fill", "commonSeriesOptions.errorBar.width", "commonSeriesOptions.errorBar.cap", "commonSeriesOptions.highlightSettings", "commonSeriesOptions.highlightSettings.enable", "commonSeriesOptions.highlightSettings.mode", "commonSeriesOptions.highlightSettings.color", "commonSeriesOptions.highlightSettings.opacity", "commonSeriesOptions.highlightSettings.border", "commonSeriesOptions.highlightSettings.pattern", "commonSeriesOptions.highlightSettings.customPattern", "commonSeriesOptions.selectionSettings", "commonSeriesOptions.selectionSettings.enable", "commonSeriesOptions.selectionSettings.type", "commonSeriesOptions.selectionSettings.mode", "commonSeriesOptions.selectionSettings.rangeType", "commonSeriesOptions.selectionSettings.color", "commonSeriesOptions.selectionSettings.opacity", "commonSeriesOptions.selectionSettings.border", "commonSeriesOptions.selectionSettings.pattern", "commonSeriesOptions.selectionSettings.customPattern", "crosshair.marker", "crosshair.marker.border", "crosshair.marker.opacity", "crosshair.marker.size", "crosshair.marker.visible", "crosshair.line", "crosshair.line.color", "crosshair.line.width", "crosshair.type", "crosshair.visible", "legend.alignment", "legend.background", "legend.border", "legend.border.color", "legend.border.width", "legend.columnCount", "legend.enableScrollbar", "legend.fill", "legend.font", "legend.font.fontFamily", "legend.font.fontStyle", "legend.font.fontWeight", "legend.font.size", "legend.itemPadding", "legend.itemStyle", "legend.itemStyle.border", "legend.itemStyle.height", "legend.itemStyle.width", "legend.location", "legend.location.x", "legend.location.y", "legend.opacity", "legend.position", "legend.rowCount", "legend.shape", "legend.size", "legend.size.height", "legend.size.width", "legend.title", "legend.title.font", "legend.title.text", "legend.title.textAlignment", "legend.textOverflow", "legend.textWidth", "legend.visible", "primaryXAxis.alternateGridBand", "primaryXAxis.alternateGridBand.even", "primaryXAxis.alternateGridBand.odd", "primaryXAxis.crossesAt", "primaryXAxis.crossesInAxis", "primaryXAxis.isIndexed", "primaryXAxis.axisLine", "primaryXAxis.axisLine.dashArray", "primaryXAxis.axisLine.offset", "primaryXAxis.axisLine.visible", "primaryXAxis.axisLine.width", "primaryXAxis.columnIndex", "primaryXAxis.columnSpan", "primaryXAxis.crosshairLabel", "primaryXAxis.crosshairLabel.visible", "primaryXAxis.desiredIntervals", "primaryXAxis.edgeLabelPlacement", "primaryXAxis.enableTrim", "primaryXAxis.font", "primaryXAxis.font.fontFamily", "primaryXAxis.font.fontStyle", "primaryXAxis.font.fontWeight", "primaryXAxis.font.opacity", "primaryXAxis.font.size", "primaryXAxis.intervalType", "primaryXAxis.isInversed", "primaryXAxis.labelFormat", "primaryXAxis.labelIntersectAction", "primaryXAxis.labelPosition", "primaryXAxis.labelRotation", "primaryXAxis.logBase", "primaryXAxis.majorGridLines", "primaryXAxis.majorGridLines.dashArray", "primaryXAxis.majorGridLines.color", "primaryXAxis.majorGridLines.opacity", "primaryXAxis.majorGridLines.visible", "primaryXAxis.majorGridLines.width", "primaryXAxis.majorTickLines", "primaryXAxis.majorTickLines.size", "primaryXAxis.majorTickLines.visible", "primaryXAxis.majorTickLines.width", "primaryXAxis.maximumLabels", "primaryXAxis.maximumLabelWidth", "primaryXAxis.minorGridLines", "primaryXAxis.minorGridLines.dashArray", "primaryXAxis.minorGridLines.visible", "primaryXAxis.minorGridLines.width", "primaryXAxis.minorTickLines", "primaryXAxis.minorTickLines.size", "primaryXAxis.minorTickLines.visible", "primaryXAxis.minorTickLines.width", "primaryXAxis.minorTicksPerInterval", "primaryXAxis.name", "primaryXAxis.opposedPosition", "primaryXAxis.plotOffset", "primaryXAxis.range", "primaryXAxis.range.min", "primaryXAxis.range.max", "primaryXAxis.range.interval", "primaryXAxis.rangePadding", "primaryXAxis.roundingPlaces", "primaryXAxis.tickLinesPosition", "primaryXAxis.title", "primaryXAxis.title.enableTrim", "primaryXAxis.title.font", "primaryXAxis.title.maximumTitleWidth", "primaryXAxis.title.text", "primaryXAxis.title.visible", "primaryXAxis.valueType", "primaryXAxis.visible", "primaryXAxis.zoomFactor", "primaryXAxis.zoomPosition", "primaryYAxis.alternateGridBand", "primaryYAxis.alternateGridBand.even", "primaryYAxis.alternateGridBand.odd", "primaryYAxis.axisLine", "primaryYAxis.axisLine.dashArray", "primaryYAxis.axisLine.offset", "primaryYAxis.axisLine.visible", "primaryYAxis.axisLine.width", "primaryYAxis.crossesAt", "primaryYAxis.crossesInAxis", "primaryYAxis.crosshairLabel", "primaryYAxis.crosshairLabel.visible", "primaryYAxis.desiredIntervals", "primaryYAxis.edgeLabelPlacement", "primaryYAxis.enableTrim", "primaryYAxis.font", "primaryYAxis.font.fontFamily", "primaryYAxis.font.fontStyle", "primaryYAxis.font.fontWeight", "primaryYAxis.font.opacity", "primaryYAxis.font.size", "primaryYAxis.intervalType", "primaryYAxis.isInversed", "primaryYAxis.labelFormat", "primaryYAxis.labelIntersectAction", "primaryYAxis.labelPosition", "primaryYAxis.logBase", "primaryYAxis.majorGridLines", "primaryYAxis.majorGridLines.dashArray", "primaryYAxis.majorGridLines.color", "primaryYAxis.majorGridLines.opacity", "primaryYAxis.majorGridLines.visible", "primaryYAxis.majorGridLines.width", "primaryYAxis.majorTickLines", "primaryYAxis.majorTickLines.size", "primaryYAxis.majorTickLines.visible", "primaryYAxis.majorTickLines.width", "primaryYAxis.maximumLabels", "primaryYAxis.maximumLabelWidth", "primaryYAxis.minorGridLines", "primaryYAxis.minorGridLines.dashArray", "primaryYAxis.minorGridLines.visible", "primaryYAxis.minorGridLines.width", "primaryYAxis.minorTickLines", "primaryYAxis.minorTickLines.size", "primaryYAxis.minorTickLines.visible", "primaryYAxis.minorTickLines.width", "primaryYAxis.minorTicksPerInterval", "primaryYAxis.name", "primaryYAxis.opposedPosition", "primaryYAxis.plotOffset", "primaryYAxis.range", "primaryYAxis.range.min", "primaryYAxis.range.max", "primaryYAxis.range.interval", "primaryYAxis.rangePadding", "primaryYAxis.roundingPlaces", "primaryYAxis.rowIndex", "primaryYAxis.rowSpan", "primaryYAxis.tickLinesPosition", "primaryYAxis.title", "primaryYAxis.title.enableTrim", "primaryYAxis.title.font", "primaryYAxis.title.maximumTitleWidth", "primaryYAxis.title.text", "primaryYAxis.title.visible", "primaryYAxis.valueType", "primaryYAxis.visible", "primaryYAxis.zoomFactor", "primaryYAxis.zoomPosition", "size.height", "size.width", "title.background", "title.border", "title.border.width", "title.border.color", "title.border.opacity", "title.border.cornerRadius", "title.font", "title.font.fontFamily", "title.font.fontStyle", "title.font.fontWeight", "title.font.opacity", "title.font.size", "title.subTitle", "title.subTitle.font", "title.subTitle.background", "title.subTitle.border", "title.subTitle.text", "title.subTitle.textAlignment", "title.text", "title.textAlignment", "zooming.enable", "zooming.enablePinching", "zooming.enableDeferredZoom", "zooming.enableMouseWheel", "zooming.type", "zooming.toolbarItems", "annotations", "columnDefinitions", "indicators", "rowDefinitions", "series", "commonSeriesOptions.trendlines", "primaryXAxis.stripLine", "primaryYAxis.stripLine"  ],[  ]);
export var ChartComponent = CreateComponent("Chart", {
    selector: 'ej-chart',
    inputs : Inputs,
    outputs : Outputs,
    template:"",
    queries: {
        _series : new ContentChild(SeriesCollectionDirective),
        _indicators : new ContentChild(IndicatorsDirective),
        _annotations : new ContentChild(AnnotationsDirective),
        _primaryXAxis_stripLine : new ContentChild(PrimaryXAxisStripLineCollectionDirective),
        _primaryYAxis_stripLine : new ContentChild(PrimaryYAxisStripLineCollectionDirective),
        _rowDefinitions : new ContentChild(RowDefinitionsDirective),
        _columnDefinitions : new ContentChild(ColumnDefinitionsDirective),
    }
},{
   tags : ["series", "indicators", "annotations", "primaryXAxis.stripLine", "primaryYAxis.stripLine", "rowDefinitions", "columnDefinitions"], 
   twoways : [  ],  
   complexes : ComplexProperties,
});

export const EJ_CHART_COMPONENTS: Type<any>[] = [ChartComponent  , TrendlinesDirective, PointsDirective, SeriesCollectionDirective, IndicatorsDirective, AnnotationsDirective, PrimaryXAxisStripLineCollectionDirective, PrimaryYAxisStripLineCollectionDirective, RowDefinitionsDirective, ColumnDefinitionsDirective, TrendlineDirective, PointDirective, SeriesDirective, IndicatorDirective, AnnotationDirective, PrimaryXAxisStripLineDirective, PrimaryYAxisStripLineDirective, RowDefinitionDirective, ColumnDefinitionDirective]

 
