import {CreateArrayTagDirective, CreateControlValueAccessor, CreateComplexDirective, CreateComponent, Utils, ContentChild, Type, forwardRef } from './core';
export var PointerDirective = CreateComplexDirective({
    selector: "e-pointers>e-pointer",
    inputs: ["backgroundColor", "backNeedleLength", "border", "distanceFromScale", "gradients", "imageUrl", "length", "markerType", "needleType", "opacity", "placement", "pointerValueText", "showBackNeedle", "type", "value", "width"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => CircularGaugeComponent)
});


export var PointersDirective = CreateArrayTagDirective("pointers", 'e-scales>e-pointers', PointerDirective);

export var LabelDirective = CreateComplexDirective({
    selector: "e-labels>e-label",
    inputs: ["angle", "autoAngle", "color", "distanceFromScale", "font", "includeFirstValue", "opacity", "placement", "type", "unitText", "unitTextPosition"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => CircularGaugeComponent)
});


export var LabelsDirective = CreateArrayTagDirective("labels", 'e-scales>e-labels', LabelDirective);

export var TickDirective = CreateComplexDirective({
    selector: "e-ticks>e-tick",
    inputs: ["angle", "color", "distanceFromScale", "height", "placement", "type", "width"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => CircularGaugeComponent)
});


export var TicksDirective = CreateArrayTagDirective("ticks", 'e-scales>e-ticks', TickDirective);

export var RangeDirective = CreateComplexDirective({
    selector: "e-ranges>e-range",
    inputs: ["backgroundColor", "border", "distanceFromScale", "endValue", "endWidth", "gradients", "opacity", "placement", "size", "startValue", "startWidth"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => CircularGaugeComponent)
});


export var RangesDirective = CreateArrayTagDirective("ranges", 'e-scales>e-ranges', RangeDirective);

export var StateRangeDirective = CreateComplexDirective({
    selector: "e-stateranges>e-staterange",
    inputs: ["backgroundColor", "borderColor", "endValue", "font", "startValue", "text", "textColor"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => CircularGaugeComponent)
});


export var StateRangesDirective = CreateArrayTagDirective("stateRanges", 'e-indicators>e-stateranges', StateRangeDirective);

export var IndicatorDirective = CreateComplexDirective({
    selector: "e-indicators>e-indicator",
    inputs: ["height", "imageUrl", "position", "stateRanges", "type", "width"],
    queries: {
        _stateRanges : new ContentChild(StateRangesDirective),
    }
}, {
    tags: ["stateRanges" ],
     type: forwardRef(() => CircularGaugeComponent)
});


export var IndicatorsDirective = CreateArrayTagDirective("indicators", 'e-scales>e-indicators', IndicatorDirective);

export var SubGaugeDirective = CreateComplexDirective({
    selector: "e-subgauges>e-subgauge",
    inputs: ["height", "position", "width"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => CircularGaugeComponent)
});


export var SubGaugesDirective = CreateArrayTagDirective("subGauges", 'e-scales>e-subgauges', SubGaugeDirective);

export var ScaleDirective = CreateComplexDirective({
    selector: "e-scales>e-scale",
    inputs: ["backgroundColor", "border", "direction", "customLabels", "indicators", "labels", "majorIntervalValue", "maximum", "minimum", "minorIntervalValue", "opacity", "pointerCap", "pointers", "radius", "ranges", "shadowOffset", "showIndicators", "showLabels", "showPointers", "showRanges", "showScaleBar", "showTicks", "size", "startAngle", "subGauges", "sweepAngle", "ticks"],
    queries: {
        _pointers : new ContentChild(PointersDirective),
        _labels : new ContentChild(LabelsDirective),
        _ticks : new ContentChild(TicksDirective),
        _ranges : new ContentChild(RangesDirective),
        _indicators : new ContentChild(IndicatorsDirective),
        _subGauges : new ContentChild(SubGaugesDirective),
    }
}, {
    tags: ["pointers", "labels", "ticks", "ranges", "indicators", "subGauges" ],
     type: forwardRef(() => CircularGaugeComponent)
});


export var ScalesDirective = CreateArrayTagDirective("scales", 'ej-circulargauge>e-scales', ScaleDirective);


var Outputs = [ "drawCustomLabel", "drawIndicators", "drawLabels", "drawPointerCap", "drawPointers", "drawRange", "drawTicks", "load", "mouseClick", "mouseClickMove", "mouseClickUp", "renderComplete" , "model.valueChange: valueChange", "model.minimumChange: minimumChange", "model.maximumChange: maximumChange"];
var ComplexProperties = [ "frame", "scales", "tooltip", "scales.border", "scales.pointerCap"  ];
var Inputs = Utils.AngularizeInputs( [ "animationSpeed", "backgroundColor", "distanceFromCorner", "enableAnimation", "frame", "gaugePosition", "height", "interiorGradient", "isRadialGradient", "isResponsive", "outerCustomLabelPosition", "radius", "readOnly", "scales", "theme", "tooltip", "width", "frame.backgroundImageUrl", "frame.frameType", "frame.halfCircleFrameEndAngle", "frame.halfCircleFrameStartAngle", "scales.backgroundColor", "scales.border", "scales.border.color", "scales.border.width", "scales.direction", "scales.majorIntervalValue", "scales.maximum", "scales.minimum", "scales.minorIntervalValue", "scales.opacity", "scales.pointerCap", "scales.pointerCap.backgroundColor", "scales.pointerCap.borderColor", "scales.pointerCap.borderWidth", "scales.pointerCap.interiorGradient", "scales.pointerCap.radius", "scales.radius", "scales.shadowOffset", "scales.showIndicators", "scales.showLabels", "scales.showPointers", "scales.showRanges", "scales.showScaleBar", "scales.showTicks", "scales.size", "scales.startAngle", "scales.sweepAngle", "tooltip.showCustomLabelTooltip", "tooltip.showLabelTooltip", "tooltip.templateID", "scales.customLabels", "scales.indicators", "scales.labels", "scales.pointers", "scales.ranges", "scales.subGauges", "scales.ticks"  ],["value", "minimum", "maximum"  ]);
export var CircularGaugeComponent = CreateComponent("CircularGauge", {
    selector: 'ej-circulargauge',
    inputs : Inputs,
    outputs : Outputs,
    template:"",
    queries: {
        _scales : new ContentChild(ScalesDirective),
    }
},{
   tags : ["scales"], 
   twoways : ["value", "minimum", "maximum"  ],  
   complexes : ComplexProperties,
});

export const EJ_CIRCULARGAUGE_COMPONENTS: Type<any>[] = [CircularGaugeComponent  , PointersDirective, LabelsDirective, TicksDirective, RangesDirective, StateRangesDirective, IndicatorsDirective, SubGaugesDirective, ScalesDirective, PointerDirective, LabelDirective, TickDirective, RangeDirective, StateRangeDirective, IndicatorDirective, SubGaugeDirective, ScaleDirective]

 
