import {CreateArrayTagDirective, CreateControlValueAccessor, CreateComplexDirective, CreateComponent, Utils, ContentChild, Type, forwardRef } from './core';
export var MarkerPointerDirective = CreateComplexDirective({
    selector: "e-markerpointers>e-markerpointer",
    inputs: ["backgroundColor", "border", "distanceFromScale", "gradients", "length", "opacity", "placement", "type", "value", "width"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => LinearGaugeComponent)
});


export var MarkerPointersDirective = CreateArrayTagDirective("markerPointers", 'e-scales>e-markerpointers', MarkerPointerDirective);

export var BarPointerDirective = CreateComplexDirective({
    selector: "e-barpointers>e-barpointer",
    inputs: ["backgroundColor", "border", "distanceFromScale", "gradients", "opacity", "value", "width"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => LinearGaugeComponent)
});


export var BarPointersDirective = CreateArrayTagDirective("barPointers", 'e-scales>e-barpointers', BarPointerDirective);

export var RangeDirective = CreateComplexDirective({
    selector: "e-ranges>e-range",
    inputs: ["backgroundColor", "border", "distanceFromScale", "endValue", "endWidth", "gradients", "opacity", "placement", "startValue", "startWidth"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => LinearGaugeComponent)
});


export var RangesDirective = CreateArrayTagDirective("ranges", 'e-scales>e-ranges', RangeDirective);

export var TickDirective = CreateComplexDirective({
    selector: "e-ticks>e-tick",
    inputs: ["angle", "color", "distanceFromScale", "height", "opacity", "placement", "type", "width"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => LinearGaugeComponent)
});


export var TicksDirective = CreateArrayTagDirective("ticks", 'e-scales>e-ticks', TickDirective);

export var StateRangeDirective = CreateComplexDirective({
    selector: "e-stateranges>e-staterange",
    inputs: ["backgroundColor", "borderColor", "endValue", "startValue", "text", "textColor"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => LinearGaugeComponent)
});


export var StateRangesDirective = CreateArrayTagDirective("stateRanges", 'e-indicators>e-stateranges', StateRangeDirective);

export var IndicatorDirective = CreateComplexDirective({
    selector: "e-indicators>e-indicator",
    inputs: ["backgroundColor", "border", "font", "height", "opacity", "position", "stateRanges", "textLocation", "type", "width"],
    queries: {
        _stateRanges : new ContentChild(StateRangesDirective),
    }
}, {
    tags: ["stateRanges" ],
     type: forwardRef(() => LinearGaugeComponent)
});


export var IndicatorsDirective = CreateArrayTagDirective("indicators", 'e-scales>e-indicators', IndicatorDirective);

export var LabelDirective = CreateComplexDirective({
    selector: "e-labels>e-label",
    inputs: ["angle", "distanceFromScale", "font", "includeFirstValue", "opacity", "placement", "textColor", "type", "unitText", "unitTextPlacement"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => LinearGaugeComponent)
});


export var LabelsDirective = CreateArrayTagDirective("labels", 'e-scales>e-labels', LabelDirective);

export var ScaleDirective = CreateComplexDirective({
    selector: "e-scales>e-scale",
    inputs: ["backgroundColor", "barPointers", "border", "customLabels", "direction", "indicators", "labels", "length", "majorIntervalValue", "markerPointers", "maximum", "minimum", "minorIntervalValue", "opacity", "position", "ranges", "shadowOffset", "showBarPointers", "showCustomLabels", "showIndicators", "showLabels", "showMarkerPointers", "showRanges", "showTicks", "ticks", "type", "width"],
    queries: {
        _markerPointers : new ContentChild(MarkerPointersDirective),
        _barPointers : new ContentChild(BarPointersDirective),
        _ranges : new ContentChild(RangesDirective),
        _ticks : new ContentChild(TicksDirective),
        _indicators : new ContentChild(IndicatorsDirective),
        _labels : new ContentChild(LabelsDirective),
    }
}, {
    tags: ["markerPointers", "barPointers", "ranges", "ticks", "indicators", "labels" ],
     type: forwardRef(() => LinearGaugeComponent)
});


export var ScalesDirective = CreateArrayTagDirective("scales", 'ej-lineargauge>e-scales', ScaleDirective);


var Outputs = [ "drawBarPointers", "drawCustomLabel", "drawIndicators", "drawLabels", "drawMarkerPointers", "drawRange", "drawTicks", "init", "load", "mouseClick", "mouseClickMove", "mouseClickUp", "renderComplete" , "model.valueChange: valueChange", "model.minimumChange: minimumChange", "model.maximumChange: maximumChange"];
var ComplexProperties = [ "frame", "scales", "tooltip", "scales.border", "scales.position"  ];
var Inputs = Utils.AngularizeInputs( [ "animationSpeed", "backgroundColor", "borderColor", "enableAnimation", "enableMarkerPointerAnimation", "isResponsive", "frame", "height", "labelColor", "orientation", "outerCustomLabelPosition", "pointerGradient1", "pointerGradient2", "readOnly", "scales", "theme", "tickColor", "tooltip", "width", "frame.backgroundImageUrl", "frame.innerWidth", "frame.outerWidth", "scales.backgroundColor", "scales.border", "scales.border.color", "scales.border.width", "scales.direction", "scales.length", "scales.majorIntervalValue", "scales.maximum", "scales.minimum", "scales.minorIntervalValue", "scales.opacity", "scales.position", "scales.position.x", "scales.position.y", "scales.shadowOffset", "scales.showBarPointers", "scales.showCustomLabels", "scales.showIndicators", "scales.showLabels", "scales.showMarkerPointers", "scales.showRanges", "scales.showTicks", "scales.type", "scales.width", "tooltip.showCustomLabelTooltip", "tooltip.showLabelTooltip", "tooltip.templateID", "scales.barPointers", "scales.customLabels", "scales.indicators", "scales.labels", "scales.markerPointers", "scales.ranges", "scales.ticks"  ],["value", "minimum", "maximum"  ]);
export var LinearGaugeComponent = CreateComponent("LinearGauge", {
    selector: 'ej-lineargauge',
    inputs : Inputs,
    outputs : Outputs,
    template:"",
    queries: {
        _scales : new ContentChild(ScalesDirective),
    }
},{
   tags : ["scales"], 
   twoways : ["value", "minimum", "maximum"  ],  
   complexes : ComplexProperties,
});

export const EJ_LINEARGAUGE_COMPONENTS: Type<any>[] = [LinearGaugeComponent  , MarkerPointersDirective, BarPointersDirective, RangesDirective, TicksDirective, StateRangesDirective, IndicatorsDirective, LabelsDirective, ScalesDirective, MarkerPointerDirective, BarPointerDirective, RangeDirective, TickDirective, StateRangeDirective, IndicatorDirective, LabelDirective, ScaleDirective]

 
