import {CreateArrayTagDirective, CreateControlValueAccessor, CreateComplexDirective, CreateComponent, Utils, ContentChild, Type, forwardRef } from './core';
export var PageDirective = CreateComplexDirective({
    selector: "e-applicationtab-backstagesettings-pages>e-page",
    inputs: ["id", "text", "itemType", "contentID", "enableSeparator"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => RibbonComponent)
});


export var ApplicationTabBackstageSettingsPagesDirective = CreateArrayTagDirective("applicationTab.backstageSettings.pages", 'ej-ribbon>e-applicationtab-backstagesettings-pages', PageDirective);

export var ContentGroupDirective = CreateComplexDirective({
    selector: "e-contentgroups>e-contentgroup",
    inputs: ["buttonSettings", "columns", "contentID", "cssClass", "customGalleryItems", "customToolTip", "dropdownSettings", "enableSeparator", "expandedColumns", "galleryItems", "id", "isBig", "itemHeight", "itemWidth", "splitButtonSettings", "text", "toggleButtonSettings", "toolTip", "quickAccessMode", "type"],
    queries: {
    }
}, {
    tags: [ ],
     type: forwardRef(() => RibbonComponent)
});


export var ContentGroupsDirective = CreateArrayTagDirective("groups", 'e-content>e-contentgroups', ContentGroupDirective);

export var ContentDirective = CreateComplexDirective({
    selector: "e-contents>e-content",
    inputs: ["defaults", "groups"],
    queries: {
        _groups : new ContentChild(ContentGroupsDirective),
    }
}, {
    tags: ["groups" ],
     type: forwardRef(() => RibbonComponent)
});


export var ContentsDirective = CreateArrayTagDirective("content", 'e-groups>e-contents', ContentDirective);

export var GroupDirective = CreateComplexDirective({
    selector: "e-groups>e-group",
    inputs: ["alignType", "content", "contentID", "customContent", "enableGroupExpander", "groupExpanderSettings", "text", "type"],
    queries: {
        _content : new ContentChild(ContentsDirective),
    }
}, {
    tags: ["content" ],
     type: forwardRef(() => RibbonComponent)
});


export var GroupsDirective = CreateArrayTagDirective("groups", 'e-tabs>e-groups', GroupDirective);

export var TabDirective = CreateComplexDirective({
    selector: "e-tabs>e-tab",
    inputs: ["groups", "id", "text"],
    queries: {
        _groups : new ContentChild(GroupsDirective),
    }
}, {
    tags: ["groups" ],
     type: forwardRef(() => RibbonComponent)
});


export var TabsDirective = CreateArrayTagDirective("tabs", 'ej-ribbon>e-tabs', TabDirective);


var Outputs = [ "beforeTabRemove", "create", "destroy", "groupClick", "groupExpand", "galleryItemClick", "backstageItemClick", "collapse", "expand", "load", "tabAdd", "tabClick", "tabCreate", "tabRemove", "tabSelect", "toggleButtonClick", "qatMenuItemClick" ];
var ComplexProperties = [ "collapsePinSettings", "expandPinSettings", "applicationTab", "applicationTab.backstageSettings"  ];
var Inputs = Utils.AngularizeInputs( [ "allowResizing", "isResponsive", "isMobileOnly", "buttonDefaults", "showQAT", "collapsePinSettings", "enableRTL", "expandPinSettings", "applicationTab", "disabledItemIndex", "enabledItemIndex", "selectedItemIndex", "locale", "width", "collapsePinSettings.toolTip", "collapsePinSettings.customToolTip", "expandPinSettings.toolTip", "expandPinSettings.customToolTip", "applicationTab.backstageSettings", "applicationTab.backstageSettings.text", "applicationTab.backstageSettings.height", "applicationTab.backstageSettings.width", "applicationTab.backstageSettings.headerWidth", "applicationTab.menuItemID", "applicationTab.menuSettings", "applicationTab.type", "contextualTabs", "tabs", "applicationTab.backstageSettings.pages", "tabs.groups.content", "tabs.groups.content.groups.customGalleryItems", "tabs.groups.content.groups.galleryItems"  ],[  ]);
export var RibbonComponent = CreateComponent("Ribbon", {
    selector: 'ej-ribbon',
    inputs : Inputs,
    outputs : Outputs,
    template:"",
    queries: {
        _applicationTab_backstageSettings_pages : new ContentChild(ApplicationTabBackstageSettingsPagesDirective),
        _tabs : new ContentChild(TabsDirective),
    }
},{
   tags : ["applicationTab.backstageSettings.pages", "tabs"], 
   twoways : [  ],  
   complexes : ComplexProperties,
});

export const EJ_RIBBON_COMPONENTS: Type<any>[] = [RibbonComponent  , ApplicationTabBackstageSettingsPagesDirective, ContentGroupsDirective, ContentsDirective, GroupsDirective, TabsDirective, PageDirective, ContentGroupDirective, ContentDirective, GroupDirective, TabDirective]

 
